# src/chuk_mcp_linkedin/posts/components/layout/__init__.py
"""
Layout components for LinkedIn posts.

Visual spacing and structure elements.
"""

from .separator import Separator

__all__ = [
    "Separator",
]
